![Logo](https://user-images.githubusercontent.com/48266854/121274136-3a196f00-c8a0-11eb-9625-3b637054867f.png)



[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4723864.svg)](https://doi.org/10.5281/zenodo.4723864)
![GitHub repo size](https://img.shields.io/github/repo-size/HighEloDevs/Analysis-Tool-for-Undergrad-Students)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/HighEloDevs/Analysis-Tool-for-Undergrad-Students)
![Codacy grade](https://img.shields.io/codacy/grade/f47977a1c98547699611f8b4a40614a4)
![GitHub all releases](https://img.shields.io/github/downloads/HighEloDevs/Analysis-Tool-for-Undergrad-Students/total)
[![MIT License](https://img.shields.io/apm/l/atomic-design-ui.svg?)](https://highelodevs.github.io/Analysis-Tool-for-Undergrad-Students/license/)



O **A**nalysis **T**ool for **U**ndergrad **S**tudents é uma ferramenta desenvolvida por estudantes da **Universidade de São Paulo**, com o objetivo de facilitar a análise de dados feita por estudantes de física experimental.



## Documentação
Instruções para instalação e tutoriais de uso do ATUS podem ser encontradas na nossa [página](https://highelodevs.github.io/Analysis-Tool-for-Undergrad-Students/).

## Feedback
Para qualquer crítica construtiva, sugestões, reportes de bugs etc, por favor, nos envie um e-mail - atusdevs@gmail.com

## Autores
- [@GuiiFerrari](https://github.com/GuiiFerrari)
- [@LeoEiji](https://github.com/leoeiji)
- [@imscl_](https://www.instagram.com/imscl_/)
